* Prevent "more" messages from appearing
set more off
* Control line length
set linesize 150

********************************************************************************
*******             BEGIN DATA MANIPULATION FOR CHAPTER 2 EXAMPLE        *******
*******               CHANGE "filesave" to your directory                *******
********************************************************************************

* Defining global variable for file location to be replaced in code below
global filesave "C:\Dropbox\14_SPLH861\861_Example1"

* Import chapter 2 data into temporary file
use "$filesave\STATA_Chapter2.dta", clear
* Center continuous predictors
gen age85 = age - 85
gen grip9 = grip - 9
* Re-coding sex so women are reference (unnecessary)
gen sexwm = sexmw
recode sexwm (1=0) if sexmw==1
recode sexwm (0=1) if sexmw==0
* Creating contrasts for dementia groups
gen demNF=0 
gen demNC=0 
* Demgroup = none   
replace demNF=0 if (demgroup==1)
replace demNC=0 if (demgroup==1)
* Demgroup = future 
replace demNF=1 if (demgroup==2)
replace demNC=0 if (demgroup==2)
* Demgroup = current
replace demNF=0 if (demgroup==3)
replace demNC=1 if (demgroup==3)  
* Labeling new variables
label variable age85  "age85: Age in Years (0=85)"
label variable grip9  "grip9: Grip Strength in Pounds (0=9)"
label variable sexwm  "sexwm: Sex (0=Women, 1=Men)"
label variable demNF  "demNF: Dementia Contrast for None=0 vs Future=1"
label variable demNC  "demNC: Dementia Contrast for None=0 vs Current=1"
    
********************************************************************************
*******                       BEGIN EXAMPLE 1 MODELS                     *******
********************************************************************************

* Save results to separate file
log using $filesave\STATA_Example1_Output.log, replace name(STATA_Example1)

display as result "Chapter 2: Descriptive Statistics for Example Variables"
summarize age grip cognition
tabulate sexmw demgroup
corr age grip sexmw cognition 

display as result "Eq 2.3: Empty Means Model"
mixed cognition , ///
         || caseid: , noconstant variance reml,
      estat ic, n(550),

display as result "Eq 2.4: Adding Age 0=85"
mixed cognition c.age85, ///
         || caseid: , noconstant variance reml,
      estat ic, n(550),

display as result "Eq 2.6: Adding Grip 0=9"
mixed cognition c.age85 c.grip9, ///
         || caseid: , noconstant variance reml,
      estat ic, n(550),
      test (c.age85=0) (c.grip9=0) // Model R2 Test

display as result "Eq 2.7: Adding Sex 0=M 1=W"
mixed cognition c.age85 c.grip9 c.sexmw, ///
         || caseid: , noconstant variance reml,
      estat ic, n(550),
      lincom _cons*1 + c.sexmw*1 // Intercept for Women
      test (c.age85=0) (c.grip9=0) (c.sexmw=0) // Model R2 Test

display as result "Eq 2.8: Adding Dementia Group"
display as result "Using Manual Group Contrasts so Reference=None"
mixed cognition c.age85 c.grip9 c.sexmw c.demNF c.demNC, ///
         || caseid: , noconstant variance reml,
      estat ic, n(550),
      test (c.age85=0) (c.grip9=0) (c.sexmw=0) (c.demNF=0) (c.demNC=0) // Model R2 Chi2 Test
      test (c.demNF=0) (c.demNC=0) // Omnibus Chi2-Test for Dementia Group
      lincom _cons*1 + c.demNF*0 + c.demNC*0 // Intercept for None Group
      lincom _cons*1 + c.demNF*1 + c.demNC*0 // Intercept for Future Group
      lincom _cons*1 + c.demNF*0 + c.demNC*1 // Intercept for Current Group
      lincom c.demNF*1 + c.demNC*0  // None   vs Future  Group
      lincom c.demNF*0 + c.demNC*1  // None   vs Current Group
      lincom c.demNF*-1 + c.demNC*1 // Future vs Current Group
      
* Close log
log close STATA_Example1
